@@ -4,8 +4,23 @@ package Test::Mail::Pyzor;
 # All rights reserved.
 # http://cpanel.net
 #
-# This is free software; you can redistribute it and/or modify it under the
-# Apache 2.0 license.
+# <@LICENSE>
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to you under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at:
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+# </@LICENSE>
+#
 
 use strict;
 use warnings;
@@ -45,7 +60,7 @@ sub get_test_emails_hr {
 my $_python_bin;
 
 sub python_bin {
-    return $_python_bin ||= File::Which::which('python');
+    return $_python_bin ||= File::Which::which('python') || File::Which::which('python2');
 }
 
 my $_python_can_load_pyzor;
